"""Admin models for the mainapp app."""

from django.contrib import admin

from .models import Peg, Member, Team, Section


@admin.register(Peg)
class PegAdmin(admin.ModelAdmin):
    """Admin model for the Peg model."""

    change_list_template = "entities/bulk_pegging.html"
    readonly_fields = ("peg_number",)
    list_display = ("peg_number",)
    search_fields = ("peg_number",)


@admin.register(Member)
class MemberAdmin(admin.ModelAdmin):
    """Admin model for the Member model."""

    list_display = ("first_name", "last_name", "user", "team", "peg")
    search_fields = ("first_name", "last_name", "user", "team", "peg")
    list_filter = ("team", "peg")


@admin.register(Team)
class TeamAdmin(admin.ModelAdmin):
    """Admin model for the Team model."""

    readonly_fields = ("team_number",)
    list_display = ("team_number",)
    search_fields = ("team_number",)


@admin.register(Section)
class SectionAdmin(admin.ModelAdmin):
    """Admin model for the Section model."""

    list_display = ("character",)
    search_fields = ("character",)
